@@ -2,4 +2,5 @@ from django.apps import AppConfig
 
 
 class DjaqUiConfig(AppConfig):
-    name = "djaq_ui"
+    name = "djaq.djaq_ui"
+    label = "djaq_ui"
